OTHER_ERROR property
Indicates a failure other than that of trust evaluation.
This value indicates that evaluation failed for some other reason. This can be caused by either a revoked certificate or by OS-level errors that are unrelated to the certificates themselves.
Officially Supported Platforms/Implementations:
Implementation
static final OTHER_ERROR =
SslErrorType._internalMultiPlatform('OTHER_ERROR', () {
switch (defaultTargetPlatform) {
case TargetPlatform.iOS:
return 7;
case TargetPlatform.macOS:
return 7;
default:
break;
}
return null;
});